/****************************************************************************************/
/*** modification story                                                           *******/
// 24/04/04 : Linux version (MDK 9.2)
/****************************************************************************************/
// Lowlevel.c for stepper motor
//
// Pinout :
// D0=STEP
// D1=DIRECTION
// D2=ENABLE Power
/****************************************************************************************/

//********* include ***********
#include "MyTypes.h"
#include "MyGlobals.h"
#include "lowlevel.h"
#include "driver.h"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>



//********* functions *********
//*****************************************************************************
// Internal Function :
// init	:	init the pan & tilt mount
// returns : COK : normal execution
//			OPEN_DRIVER_READ_ERR: open driver for read error
//			OPEN_DRIVER_WRITE_ERR: open driver for write error
//*****************************************************************************
int InitMount(void)
{
 if (ioperm(ParallelPortBaseAddress,1,1))
	return CNOK;
else
	return COK;

}

//*****************************************************************************
// Internal Function : 
// close	:	close the parallel port driver under windows NT
// returns : COK : normal execution
//			OPEN_DRIVER_READ_ERR: open driver for read error
//			OPEN_DRIVER_WRITE_ERR: open driver for write error
//*****************************************************************************
int CloseMount(void)
{
	return COK;
}



//*****************************************************************************
// Internal Function : 
// Go Left	:	send a sequence to the stepper motor : turn left
// returns : COK
//			 WRITE_ERROR
//*****************************************************************************
int GoLeft(void)
{

	for ( CompteurPas = 0 ; CompteurPas < NOMBRE_DE_PAS ; CompteurPas++)
	{
		ErreurDriverLevel=WriteParPort(0xE7);
		waitus(5000);
		ErreurDriverLevel=WriteParPort(0xE6);
		waitus(5000);
	}

	ErreurDriverLevel=WriteParPort(0xE0); // power off the stepper motor

	if(ErreurDriverLevel == WRITE_ERROR)
	{
		printf("I/O Linux driver error on Write Action<br><br>\r\n");
		return (WRITE_ERROR);
	}

	return COK;


}

//*****************************************************************************
// Internal Function :
// Go Right	:	send a sequence to the stepper motor : turn right
// returns : COK
//			 WRITE_ERROR
//*****************************************************************************
int GoRight(void)
{

	for ( CompteurPas = 0 ; CompteurPas < NOMBRE_DE_PAS ; CompteurPas++)
	{
		ErreurDriverLevel=WriteParPort(0xE5);
		waitus(5000);
		ErreurDriverLevel=WriteParPort(0xE4);
		waitus(5000);
	}

	ErreurDriverLevel=WriteParPort(0xE0); // power off the stepper motor

	if(ErreurDriverLevel == WRITE_ERROR)
	{
		printf("I/O Linux driver error on Write Action<br><br>\r\n");
		return (WRITE_ERROR);
	}

	return COK;

}

//*****************************************************************************
// Internal Function : 
// Go Top	:	send a sequence to the stepper motor : turn top
// returns : COK
//			 WRITE_ERROR  
//*****************************************************************************
int GoUp(void)
{
	return COK;
}

//*****************************************************************************
// Internal Function : 
// Go Bottom	:	send a sequence to the stepper motor : turn bottom
// returns : COK
//			 WRITE_ERROR
//*****************************************************************************
int GoDown(void)
{
	return COK;
	
}

/* ------------------------------------------------------------------------
   Delay for a number of uS -- Works better than usleep for me!
   ------------------------------------------------------------------------ */
void waitus( unsigned int us )
{
  struct timeval tv, wt;

  gettimeofday( &tv, NULL );

  wt.tv_usec = ( tv.tv_usec + us ) % 1000000;
  wt.tv_sec = tv.tv_sec + ( ( tv.tv_usec + us ) / 1000000);

  /* loop until time is up */
  for (;;)
  {
    gettimeofday( &tv, NULL );
    if ( tv.tv_sec > wt.tv_sec )
      return;
    if ( tv.tv_sec == wt.tv_sec )
      if ( tv.tv_usec > wt.tv_usec )
        return;
  }
}


