/****************************************************************************************/
/*** modification story                                                           *******/
/****************************************************************************************/ 
/*	Lowlevel.c for stepper motor														*/
/*																						*/
/* Pinout :																				*/
/*			D0=STEP																		*/
/*			D1=DIRECTION																*/
/*			D2=ENABLE Power																*/
/*																						*/
/****************************************************************************************/ 

//********* include ***********
#include "MyTypes.h"
#include "myglobals.h"
#include "lowlevel.h"
#include "driver.h"

#include <conio.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <dos.h>
#include <process.h>



//********* functions *********
//*****************************************************************************
// Internal Function : 
// init	:	init the pan & tilt mount
// returns : COK : normal execution
//			OPEN_DRIVER_READ_ERR: open driver for read error
//			OPEN_DRIVER_WRITE_ERR: open driver for write error
//*****************************************************************************
int InitMount(void)
{
	if(WindowsVersion==isWindowsNT)
	{
//-> WinNT
		ErreurEndLevel=OpenParPort(); // ouvre le driver pour lire
		if( (ErreurEndLevel == OPEN_DRIVER_READ_ERR) || (ErreurEndLevel == OPEN_DRIVER_WRITE_ERR) )
		{
			return (OPEN_DRIVER_READ_ERR);
		}
		else
		{
				return COK;
		}
	}	
	else
	{ 
//-> win9x	
		
		//_outp ...

		return(COK);
	}
}

//*****************************************************************************
// Internal Function : 
// close	:	close the parallel port driver under windows NT
// returns : COK : normal execution
//			OPEN_DRIVER_READ_ERR: open driver for read error
//			OPEN_DRIVER_WRITE_ERR: open driver for write error
//*****************************************************************************
int CloseMount(void)
{
	if(WindowsVersion==isWindowsNT)
	{
//-> WinNT
		ErreurEndLevel=CloseParPort(); // ouvre le driver pour lire
		if( ErreurEndLevel == CLOSE_DRIVER_ERR )
		{
			return (CLOSE_DRIVER_ERR);
		}
		else
		{
			return COK;
		}
	}
	else
	{ 
//-> win9x	
		
		//_outp ...

		return(COK);
	}
}



//*****************************************************************************
// Internal Function : 
// Go Left	:	send a sequence to the stepper motor : turn left
// returns : COK
//			 WRITE_ERROR 
//*****************************************************************************
int GoLeft(void)
{
	TimeOut=0;

	if( WindowsVersion==isWindowsNT )	//->WinNT
	{

		for ( TimeOut = 0 ; TimeOut < 100 ; TimeOut++)
		{
			ErreurDriverLevel=WriteParPort(0xE7);
			Sleep(5);
			ErreurDriverLevel=WriteParPort(0xE6);
			Sleep(5);
		}

		ErreurDriverLevel=WriteParPort(0xE0); // power off the stepper motor

		if(ErreurDriverLevel == WRITE_ERROR)
		{
			printf("I/O NT driver error on Write Action<br><br>\r\n"); 
			return (WRITE_ERROR);
		}

		return COK;
	}
	else //->Win9x
	{
		//_outp(...);
		return COK;
	}
}

//*****************************************************************************
// Internal Function : 
// Go Right	:	send a sequence to the stepper motor : turn right
// returns : COK
//			 WRITE_ERROR
//*****************************************************************************
int GoRight(void)
{
	TimeOut=0;


	if( WindowsVersion==isWindowsNT )	//->WinNT
	{
	
		for ( TimeOut = 0 ; TimeOut < 100 ; TimeOut++)
		{
			ErreurDriverLevel=WriteParPort(0xE5);
			Sleep(5);
			ErreurDriverLevel=WriteParPort(0xE4);
			Sleep(5);
		}

		ErreurDriverLevel=WriteParPort(0xE0); // power off the stepper motor

		if(ErreurDriverLevel == WRITE_ERROR)
		{
			printf("I/O NT driver error on Write Action<br><br>\r\n"); 
			return (WRITE_ERROR);
		}

		return COK;
	}
	else //->Win9x
	{
		//_outp(...);
		return COK;
	}
}

//*****************************************************************************
// Internal Function : 
// Go Top	:	send a sequence to the stepper motor : turn top
// returns : COK
//			 WRITE_ERROR  
//*****************************************************************************
int GoUp(void)
{
	TimeOut=0;


	if( WindowsVersion==isWindowsNT )	//->WinNT
	{
		ErreurDriverLevel=WriteParPort(0xE4);
		if(ErreurDriverLevel == WRITE_ERROR)
		{
			printf("I/O NT driver error on Write Action<br><br>\r\n"); 
			return (WRITE_ERROR);
		}

		return COK;
	}
	else //->Win9x
	{
		//_outp(...);
		return COK;
	}
}

//*****************************************************************************
// Internal Function : 
// Go Bottom	:	send a sequence to the stepper motor : turn bottom
// returns : COK
//			 WRITE_ERROR
//*****************************************************************************
int GoDown(void)
{
	TimeOut=0;


	if( WindowsVersion==isWindowsNT )	//->WinNT
	{
		ErreurDriverLevel=WriteParPort(0xE8);
		if(ErreurDriverLevel == WRITE_ERROR)
		{
			printf("I/O NT driver error on Write Action<br><br>\r\n"); 
			return (WRITE_ERROR);
		}

		return COK;
	}
	else //->Win9x
	{
		//_outp(...);
		return COK;
	}
}

